@@ -17,6 +17,12 @@ class ChessMove:
     # The player and piece that moved
     player     = None
     piece      = None
+    
+    # The piece that was promoted to (or None)
+    promotion  = None
+    
+    # The victim piece (or None)
+    victim     = None
 
     # The start and end position of the move
     start      = None
@@ -26,6 +32,9 @@ class ChessMove:
     canMove    = ''
     sanMove    = ''
 
+    # The game result after this move
+    result     = None
+
 class ChessPlayer:
     """
     """
@@ -390,6 +399,7 @@ class ChessGame:
                 return
 
         # Only use promotion type if a pawn move to far file
+        victim = self.__board.getPiece(end)
         piece = self.__board.getPiece(start)
         promotion = None
         if piece is not None and piece.getType() is chess.board.PAWN:
@@ -408,17 +418,20 @@ class ChessGame:
         if moveResult is chess.board.MOVE_RESULT_ILLEGAL:
             print 'Illegal move: ' + str(move)
             return
-            
+
         move = ChessMove()
         if len(self.__moves) == 0:
             move.number = 1
         else:
             move.number = self.__moves[-1].number + 1
         move.player  = self.__currentPlayer
+        move.piece   = piece
+        move.victim  = victim
         move.start   = start
         move.end     = end
         move.canMove = canMove
         move.sanMove = sanMove
+        move.result  = moveResult
         self.__moves.append(move)
 
         # This player has now moved
@@ -428,6 +441,9 @@ class ChessGame:
         for player in self.__players:
             player.onPlayerMoved(self.__currentPlayer, move)
             
+        # Check if the game has ended
+        # ...
+            
         # Notify the next player they can move
         self.__currentPlayer = nextPlayer
         if self.__started is True:
@@ -523,4 +539,4 @@ if __name__ == '__main__':
     game.setBlack(black)
     
     game.start()
-    
\ No newline at end of file
+    
