@@ -122,6 +122,8 @@ class NewGameSelector (GameSelector):
         
     def selection_changed_cb (self, selection):
         mod,itr = selection.get_selected()
+        if itr is None:
+            return
         while mod.iter_parent(itr):
             itr = mod.iter_parent(itr)
         difficulty = mod.get_value(itr,4)
@@ -563,7 +565,7 @@ class GamePrinter (NewGameSelector):
                 parent = mod[path].parent
                 if parent and not parent.path in rows:
                     # then we select the parent...
-                    selection.select_iter(parent)
+                    selection.select_path(parent.path)
                     # and we stop handling because we should be called
                     # again as a result of our selection
                     break
