@@ -43,8 +43,18 @@ def inactivate_new_game_etc (fun):
             '/MenuBar/File/Open',
             '/MenuBar/File/ByHand',
             '/MenuBar/File/Print',
-            '/MenuBar/Edit',
-            '/MenuBar/Game',
+            '/MenuBar/Edit/Undo',
+            '/MenuBar/Edit/Redo',
+            '/MenuBar/Edit/Clear',
+            '/MenuBar/Edit/ClearNotes',
+            '/MenuBar/Game/ShowPossible',
+            '/MenuBar/Game/AutofillCurrentSquare',
+            '/MenuBar/Game/Autofill',
+            '/MenuBar/Game/AlwaysShowPossible',
+            '/MenuBar/Game/ShowImpossibleImplications',
+            '/MenuBar/Game/Tracker',
+            '/MenuBar/Game/PuzzleInfo',
+            '/MenuBar/Game/HighScores',
             ]
         for p in paths:
             action = ui.uimanager.get_action(p)
@@ -875,6 +885,8 @@ class TrackerBox (gtk.VBox):
             a.connect_proxy(self.glade.get_widget(widget_name))
         self.glade.get_widget('AddTrackerButton').connect('clicked',
                                                           self.add_tracker)
+        # Default to insensitive (they only become sensitive once a tracker is added)
+        self.tracker_actions.set_sensitive(False)
 
     @simple_debug
     def add_tracker (self,*args):
@@ -917,8 +929,11 @@ class TrackerBox (gtk.VBox):
     @simple_debug
     def clear_cb (self, action):
         mod,itr=self.tracker_tree.get_selection().get_selected()
-        selected_tracker_id=mod.get_value(itr,0)
-        self.tracker_delete_tracks(selected_tracker_id)
+        # This should only be called if there is an itr, but we'll
+        # double-check just in case.
+        if itr:
+            selected_tracker_id=mod.get_value(itr,0)
+            self.tracker_delete_tracks(selected_tracker_id)
 
     @simple_debug
     def keep_cb (self, action):
@@ -930,7 +945,7 @@ class TrackerBox (gtk.VBox):
     def tracker_delete_tracks (self, tracker_id):
         clearer=Undo.UndoableObject(
             lambda *args: self.main_ui.cleared.append(self.main_ui.gsd.delete_by_tracker(tracker_id)),
-            lambda *args: [self.main_ui.gsd.add(*entry) for entry in self.main_ui.cleared.pop()],
+            lambda *args: [self.main_ui.gsd.add_value(*entry) for entry in self.main_ui.cleared.pop()],
             self.main_ui.history)
         clearer.perform()
 
@@ -938,7 +953,7 @@ class TrackerBox (gtk.VBox):
     def tracker_keep_tracks (self, tracker_id):
         clearer=Undo.UndoableObject(
             lambda *args: self.main_ui.cleared.append(self.main_ui.gsd.delete_except_for_tracker(tracker_id)),
-            lambda *args: [self.main_ui.gsd.add(*entry) for entry in self.main_ui.cleared.pop()],
+            lambda *args: [self.main_ui.gsd.add_value(*entry) for entry in self.main_ui.cleared.pop()],
             self.main_ui.history)
         clearer.perform()
 
