@@ -19,17 +19,42 @@
  * For more details see the file COPYING.
  */
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <games-scores-dialog.h>
 #include "highscores.h"
 
+static const GamesScoresDescription scoredesc = {NULL, NULL,
+                                                 "gnometris",
+                                                 GAMES_SCORES_STYLE_PLAIN_DESCENDING};
+
+
 HighScores::HighScores ()
 {
-  dialog = games_scores_dialog_new ("gnometris", _("Gnometris Scores"));
+  highscores = games_scores_new (&scoredesc);
+
+  dialog = NULL;
 }
 
-void HighScores::show (gint highlight)
+gint HighScores::add (gint score)
 {
+  GamesScoreValue value;
+
+  value.plain = score;
+
+  return games_scores_add_score (highscores, value);
+}
+
+gboolean HighScores::empty (void)
+{
+  return games_scores_get (highscores) == NULL;
+}
+
+void HighScores::show (GtkWindow *parent_window, gint highlight)
+{
+  if (!dialog)
+    dialog = games_scores_dialog_new (parent_window, highscores, _("Gnometris Scores"));
+
   games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (dialog), highlight);
   gtk_dialog_run (GTK_DIALOG (dialog));    
   gtk_widget_hide (dialog);
