@@ -25,15 +25,13 @@
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
-
 #define GAMES_TYPE_GRID_FRAME            (games_grid_frame_get_type ())
 #define GAMES_GRID_FRAME(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GRID_FRAME, GamesGridFrame))
 #define GAMES_GRID_FRAME_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GRID_FRAME, GamesGridFrameClass))
 #define GAMES_IS_GRID_FRAME(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GRID_FRAME))
 #define GAMES_IS_GRID_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GRID_FRAME))
 #define GAMES_GRID_FRAME_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GRID_FRAME))
-
-typedef struct _GamesGridFrame {
+  typedef struct _GamesGridFrame {
   GtkBin bin;
 
   gint xmult;
@@ -42,6 +40,9 @@ typedef struct _GamesGridFrame {
   gint xpadding;
   gint ypadding;
 
+  gfloat xalign;
+  gfloat yalign;
+
   GtkAllocation old_allocation;
 } GamesGridFrame;
 
@@ -52,12 +53,12 @@ typedef struct _GamesGridFrameClass {
 GType games_grid_frame_get_type (void);
 
 GtkWidget *games_grid_frame_new (gint width, gint height);
-void games_grid_frame_set (GamesGridFrame *frame, gint width, gint height);
-void games_grid_frame_set_padding (GamesGridFrame *frame, gint xpadding, 
+void games_grid_frame_set (GamesGridFrame * frame, gint width, gint height);
+void games_grid_frame_set_padding (GamesGridFrame * frame, gint xpadding,
 				   gint ypadding);
+void games_grid_frame_set_alignment (GamesGridFrame * frame, gfloat xalign,
+				     gfloat yalign);
 
 G_END_DECLS
-
 #endif /* GAMES_GRID_FRAME_H */
-
 /* EOF */
