@@ -9,14 +9,13 @@
 #ifndef UI_H
 #define UI_H
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #define clear_message() set_message (0)
 
 void show_score (gint score);
 void set_message (gint count);
-void set_message_destroyed (gint count);
-void set_message_general (gchar *message);
+void set_message_general (gchar * message);
 void game_over_dialog (gint place);
 void new_frame_ratio (gint board_width, gint board_height);
 void build_gui (void);
